@@ -146,6 +146,188 @@ class BibleBooks:
         "132": ("T. Solomon", "Testament of Solomon"),
     }
 
+    abbrev["tc"] = {
+        "1": ("創", "創世記"),
+        "2": ("出", "出埃及記"),
+        "3": ("利", "利未記"),
+        "4": ("民", "民數記"),
+        "5": ("申", "申命記"),
+        "6": ("書", "約書亞記"),
+        "7": ("士", "士師記"),
+        "8": ("得", "路得記"),
+        "9": ("撒上", "撒母耳記上"),
+        "10": ("撒下", "撒母耳記下"),
+        "11": ("王上", "列王紀上"),
+        "12": ("王下", "列王紀下"),
+        "13": ("代上", "歷代志上"),
+        "14": ("代下", "歷代志下"),
+        "15": ("拉", "以斯拉記"),
+        "16": ("尼", "尼希米記"),
+        "17": ("斯", "以斯帖記"),
+        "18": ("伯", "約伯記"),
+        "19": ("詩", "詩篇"),
+        "20": ("箴", "箴言"),
+        "21": ("傳", "傳道書"),
+        "22": ("歌", "雅歌"),
+        "23": ("賽", "以賽亞書"),
+        "24": ("耶", "耶利米書"),
+        "25": ("哀", "耶利米哀歌"),
+        "26": ("結", "以西結書"),
+        "27": ("但", "但以理書"),
+        "28": ("何", "何西阿書"),
+        "29": ("珥", "約珥書"),
+        "30": ("摩", "阿摩司書"),
+        "31": ("俄", "俄巴底亞書"),
+        "32": ("拿", "約拿書"),
+        "33": ("彌", "彌迦書"),
+        "34": ("鴻", "那鴻書"),
+        "35": ("哈", "哈巴谷書"),
+        "36": ("番", "西番雅書"),
+        "37": ("該", "哈該書"),
+        "38": ("亞", "撒迦利亞書"),
+        "39": ("瑪", "瑪拉基書"),
+        "40": ("太", "馬太福音"),
+        "41": ("可", "馬可福音"),
+        "42": ("路", "路加福音"),
+        "43": ("約", "約翰福音"),
+        "44": ("徒", "使徒行傳"),
+        "45": ("羅", "羅馬書"),
+        "46": ("林前", "哥林多前書"),
+        "47": ("林後", "哥林多後書"),
+        "48": ("加", "加拉太書"),
+        "49": ("弗", "以弗所書"),
+        "50": ("腓", "腓立比書"),
+        "51": ("西", "歌羅西書"),
+        "52": ("帖前", "帖撒羅尼迦前書"),
+        "53": ("帖後", "帖撒羅尼迦後書"),
+        "54": ("提前", "提摩太前書"),
+        "55": ("提後", "提摩太後書"),
+        "56": ("多", "提多書"),
+        "57": ("門", "腓利門書"),
+        "58": ("來", "希伯來書"),
+        "59": ("雅", "雅各書"),
+        "60": ("彼前", "彼得前書"),
+        "61": ("彼後", "彼得後書"),
+        "62": ("約一", "約翰一書"),
+        "63": ("約二", "約翰二書"),
+        "64": ("約三", "約翰三書"),
+        "65": ("猶", "猶大書"),
+        "66": ("啟", "啟示錄"),
+        "70": ("巴錄書", "巴錄書"),
+        "71": ("但以理書補編", "但以理書補編"),
+        "72": ("三童歌", "三童歌"),
+        "73": ("比勒與大龍", "比勒與大龍"),
+        "75": ("蘇撒拿傳", "蘇撒拿傳"),
+        "76": ("以斯拉續篇上卷", "以斯拉續篇上卷"),
+        "77": ("以斯拉續篇下卷", "以斯拉續篇下卷"),
+        "78": ("以斯帖記補編", "以斯帖記補編"),
+        "79": ("耶利米書信", "耶利米書信"),
+        "80": ("猶滴傳", "猶滴傳"),
+        "81": ("馬加比一書", "馬加比一書"),
+        "82": ("馬加比二書", "馬加比二書"),
+        "83": ("馬加比三書", "馬加比三書"),
+        "84": ("馬加比四書", "馬加比四書"),
+        "85": ("瑪拿西禱言", "瑪拿西禱言"),
+        "86": ("詩篇一五一", "詩篇一五一"),
+        "87": ("便西拉智訓", "便西拉智訓"),
+        "88": ("多比傳", "多比傳"),
+        "89": ("所羅門智訓", "所羅門智訓"),
+        "90": ("所羅門詩篇", "所羅門詩篇"),
+        "91": ("頌歌", "頌歌"),
+        "92": ("老底嘉書", "老底嘉書"),
+    }
+
+    abbrev["sc"] = {
+        "1": ("创", "创世记"),
+        "2": ("出", "出埃及记"),
+        "3": ("利", "利未记"),
+        "4": ("民", "民数记"),
+        "5": ("申", "申命记"),
+        "6": ("书", "约书亚记"),
+        "7": ("士", "士师记"),
+        "8": ("得", "路得记"),
+        "9": ("撒上", "撒母耳记上"),
+        "10": ("撒下", "撒母耳记下"),
+        "11": ("王上", "列王纪上"),
+        "12": ("王下", "列王纪下"),
+        "13": ("代上", "历代志上"),
+        "14": ("代下", "历代志下"),
+        "15": ("拉", "以斯拉记"),
+        "16": ("尼", "尼希米记"),
+        "17": ("斯", "以斯帖记"),
+        "18": ("伯", "约伯记"),
+        "19": ("诗", "诗篇"),
+        "20": ("箴", "箴言"),
+        "21": ("传", "传道书"),
+        "22": ("歌", "雅歌"),
+        "23": ("赛", "以赛亚书"),
+        "24": ("耶", "耶利米书"),
+        "25": ("哀", "耶利米哀歌"),
+        "26": ("结", "以西结书"),
+        "27": ("但", "但以理书"),
+        "28": ("何", "何西阿书"),
+        "29": ("珥", "约珥书"),
+        "30": ("摩", "阿摩司书"),
+        "31": ("俄", "俄巴底亚书"),
+        "32": ("拿", "约拿书"),
+        "33": ("弥", "弥迦书"),
+        "34": ("鸿", "那鸿书"),
+        "35": ("哈", "哈巴谷书"),
+        "36": ("番", "西番雅书"),
+        "37": ("该", "哈该书"),
+        "38": ("亚", "撒迦利亚书"),
+        "39": ("玛", "玛拉基书"),
+        "40": ("太", "马太福音"),
+        "41": ("可", "马可福音"),
+        "42": ("路", "路加福音"),
+        "43": ("约", "约翰福音"),
+        "44": ("徒", "使徒行传"),
+        "45": ("罗", "罗马书"),
+        "46": ("林前", "哥林多前书"),
+        "47": ("林后", "哥林多后书"),
+        "48": ("加", "加拉太书"),
+        "49": ("弗", "以弗所书"),
+        "50": ("腓", "腓立比书"),
+        "51": ("西", "歌罗西书"),
+        "52": ("帖前", "帖撒罗尼迦前书"),
+        "53": ("帖后", "帖撒罗尼迦后书"),
+        "54": ("提前", "提摩太前书"),
+        "55": ("提后", "提摩太后书"),
+        "56": ("多", "提多书"),
+        "57": ("门", "腓利门书"),
+        "58": ("来", "希伯来书"),
+        "59": ("雅", "雅各书"),
+        "60": ("彼前", "彼得前书"),
+        "61": ("彼后", "彼得后书"),
+        "62": ("约一", "约翰一书"),
+        "63": ("约二", "约翰二书"),
+        "64": ("约三", "约翰三书"),
+        "65": ("犹", "犹大书"),
+        "66": ("启", "启示录"),
+        "70": ("巴录书", "巴录书"),
+        "71": ("但以理书补编", "但以理书补编"),
+        "72": ("三童歌", "三童歌"),
+        "73": ("比勒与大龙", "比勒与大龙"),
+        "75": ("苏撒拿传", "苏撒拿传"),
+        "76": ("以斯拉续篇上卷", "以斯拉续篇上卷"),
+        "77": ("以斯拉续篇下卷", "以斯拉续篇下卷"),
+        "78": ("以斯帖记补编", "以斯帖记补编"),
+        "79": ("耶利米书信", "耶利米书信"),
+        "80": ("犹滴传", "犹滴传"),
+        "81": ("马加比一书", "马加比一书"),
+        "82": ("马加比二书", "马加比二书"),
+        "83": ("马加比三书", "马加比三书"),
+        "84": ("马加比四书", "马加比四书"),
+        "85": ("玛拿西祷言", "玛拿西祷言"),
+        "86": ("诗篇一五一", "诗篇一五一"),
+        "87": ("便西拉智训", "便西拉智训"),
+        "88": ("多比传", "多比传"),
+        "89": ("所罗门智训", "所罗门智训"),
+        "90": ("所罗门诗篇", "所罗门诗篇"),
+        "91": ("颂歌", "颂歌"),
+        "92": ("老底嘉书", "老底嘉书"),
+    }
+
     # mapping bible book abbreviation / bible book name to book number
     name2number = {
         "Ge.": "1",
@@ -973,6 +1155,273 @@ class BibleBooks:
         "T. Sol.": "132",
         "T. Solomon": "132",
         "The Testament of Solomon": "132",
+        "创": "1",
+        "创世记": "1",
+        "創": "1",
+        "創世記": "1",
+        "出": "2",
+        "出埃及記": "2",
+        "出埃及记": "2",
+        "利": "3",
+        "利未記": "3",
+        "利未记": "3",
+        "民": "4",
+        "民数记": "4",
+        "民數記": "4",
+        "申": "5",
+        "申命記": "5",
+        "申命记": "5",
+        "书": "6",
+        "書": "6",
+        "約書亞記": "6",
+        "约书亚记": "6",
+        "士": "7",
+        "士师记": "7",
+        "士師記": "7",
+        "得": "8",
+        "路得記": "8",
+        "路得记": "8",
+        "撒上": "9",
+        "撒母耳記上": "9",
+        "撒母耳记上": "9",
+        "撒下": "10",
+        "撒母耳記下": "10",
+        "撒母耳记下": "10",
+        "列王紀上": "11",
+        "列王纪上": "11",
+        "王上": "11",
+        "列王紀下": "12",
+        "列王纪下": "12",
+        "王下": "12",
+        "代上": "13",
+        "历代志上": "13",
+        "歷代志上": "13",
+        "代下": "14",
+        "历代志下": "14",
+        "歷代志下": "14",
+        "以斯拉記": "15",
+        "以斯拉记": "15",
+        "拉": "15",
+        "尼": "16",
+        "尼希米記": "16",
+        "尼希米记": "16",
+        "以斯帖記": "17",
+        "以斯帖记": "17",
+        "斯": "17",
+        "伯": "18",
+        "約伯記": "18",
+        "约伯记": "18",
+        "詩": "19",
+        "詩篇": "19",
+        "诗": "19",
+        "诗篇": "19",
+        "箴": "20",
+        "箴言": "20",
+        "传": "21",
+        "传道书": "21",
+        "傳": "21",
+        "傳道書": "21",
+        "歌": "22",
+        "雅歌": "22",
+        "以賽亞書": "23",
+        "以赛亚书": "23",
+        "賽": "23",
+        "赛": "23",
+        "耶": "24",
+        "耶利米书": "24",
+        "耶利米書": "24",
+        "哀": "25",
+        "耶利米哀歌": "25",
+        "以西結書": "26",
+        "以西结书": "26",
+        "結": "26",
+        "结": "26",
+        "但": "27",
+        "但以理书": "27",
+        "但以理書": "27",
+        "何": "28",
+        "何西阿书": "28",
+        "何西阿書": "28",
+        "珥": "29",
+        "約珥書": "29",
+        "约珥书": "29",
+        "摩": "30",
+        "阿摩司书": "30",
+        "阿摩司書": "30",
+        "俄": "31",
+        "俄巴底亚书": "31",
+        "俄巴底亞書": "31",
+        "拿": "32",
+        "約拿書": "32",
+        "约拿书": "32",
+        "弥": "33",
+        "弥迦书": "33",
+        "彌": "33",
+        "彌迦書": "33",
+        "那鴻書": "34",
+        "那鸿书": "34",
+        "鴻": "34",
+        "鸿": "34",
+        "哈": "35",
+        "哈巴谷书": "35",
+        "哈巴谷書": "35",
+        "番": "36",
+        "西番雅书": "36",
+        "西番雅書": "36",
+        "哈該書": "37",
+        "哈该书": "37",
+        "該": "37",
+        "该": "37",
+        "亚": "38",
+        "亞": "38",
+        "撒迦利亚书": "38",
+        "撒迦利亞書": "38",
+        "玛": "39",
+        "玛拉基书": "39",
+        "瑪": "39",
+        "瑪拉基書": "39",
+        "太": "40",
+        "馬太福音": "40",
+        "马太福音": "40",
+        "可": "41",
+        "馬可福音": "41",
+        "马可福音": "41",
+        "路": "42",
+        "路加福音": "42",
+        "約": "43",
+        "約翰福音": "43",
+        "约": "43",
+        "约翰福音": "43",
+        "使徒行传": "44",
+        "使徒行傳": "44",
+        "徒": "44",
+        "罗": "45",
+        "罗马书": "45",
+        "羅": "45",
+        "羅馬書": "45",
+        "哥林多前书": "46",
+        "哥林多前書": "46",
+        "林前": "46",
+        "哥林多后书": "47",
+        "哥林多後書": "47",
+        "林后": "47",
+        "林後": "47",
+        "加": "48",
+        "加拉太书": "48",
+        "加拉太書": "48",
+        "以弗所书": "49",
+        "以弗所書": "49",
+        "弗": "49",
+        "腓": "50",
+        "腓利比书": "50",
+        "腓利比書": "50",
+        "歌罗西书": "51",
+        "歌羅西書": "51",
+        "西": "51",
+        "帖前": "52",
+        "帖撒罗尼迦前书": "52",
+        "帖撒羅尼迦前書": "52",
+        "帖后": "53",
+        "帖後": "53",
+        "帖撒罗尼迦后书": "53",
+        "帖撒羅尼迦後書": "53",
+        "提前": "54",
+        "提摩太前书": "54",
+        "提摩太前書": "54",
+        "提后": "55",
+        "提後": "55",
+        "提摩太后书": "55",
+        "提摩太後書": "55",
+        "多": "56",
+        "提多书": "56",
+        "提多書": "56",
+        "腓利門書": "57",
+        "腓利门书": "57",
+        "門": "57",
+        "门": "57",
+        "來": "58",
+        "希伯來書": "58",
+        "希伯来书": "58",
+        "来": "58",
+        "雅": "59",
+        "雅各书": "59",
+        "雅各書": "59",
+        "彼前": "60",
+        "彼得前书": "60",
+        "彼得前書": "60",
+        "彼后": "61",
+        "彼後": "61",
+        "彼得后书": "61",
+        "彼得後書": "61",
+        "約一": "62",
+        "約翰一書": "62",
+        "約翰壹書": "62",
+        "约一": "62",
+        "约翰一书": "62",
+        "约翰壹书": "62",
+        "約二": "63",
+        "約翰二書": "63",
+        "約翰貳書": "63",
+        "约二": "63",
+        "约翰二书": "63",
+        "约翰贰书": "63",
+        "約三": "64",
+        "約翰三書": "64",
+        "約翰參書": "64",
+        "约三": "64",
+        "约翰三书": "64",
+        "约翰参书": "64",
+        "犹": "65",
+        "犹大书": "65",
+        "猶": "65",
+        "猶大書": "65",
+        "启": "66",
+        "启示录": "66",
+        "啟": "66",
+        "啟示錄": "66",
+        "三童歌": "72",
+        "以斯帖記補編": "78",
+        "以斯帖记补编": "78",
+        "以斯拉續篇上卷": "76",
+        "以斯拉續篇下卷": "77",
+        "以斯拉续篇上卷": "76",
+        "以斯拉续篇下卷": "77",
+        "但以理书补编": "71",
+        "但以理書補編": "71",
+        "便西拉智訓": "87",
+        "便西拉智训": "87",
+        "多比传": "88",
+        "多比傳": "88",
+        "巴录书": "70",
+        "巴錄書": "70",
+        "所罗门智训": "89",
+        "所罗门诗篇": "90",
+        "所羅門智訓": "89",
+        "所羅門詩篇": "90",
+        "比勒与大龙": "73",
+        "比勒與大龍": "73",
+        "犹滴传": "80",
+        "猶滴傳": "80",
+        "玛拿西祷言": "85",
+        "瑪拿西禱言": "85",
+        "老底嘉书": "92",
+        "老底嘉書": "92",
+        "耶利米书信": "79",
+        "耶利米書信": "79",
+        "苏撒拿传": "75",
+        "蘇撒拿傳": "75",
+        "詩篇一五一": "86",
+        "诗篇一五一": "86",
+        "頌歌": "91",
+        "颂歌": "91",
+        "馬加比一書": "81",
+        "馬加比三書": "83",
+        "馬加比二書": "82",
+        "馬加比四書": "84",
+        "马加比一书": "81",
+        "马加比三书": "83",
+        "马加比二书": "82",
+        "马加比四书": "84",
     }
 
     chapters = {
